@@ -1,7 +1,7 @@
 #
 #   irb.rb - irb main module
 #       $Release Version: 0.9.6 $
-#       $Revision: 39075 $
+#       $Revision: 54263 $
 #       by Keiju ISHITSUKA(keiju@ruby-lang.org)
 #
 # --
@@ -21,16 +21,16 @@ require "irb/locale"
 
 STDOUT.sync = true
 
-# IRB stands for "interactive ruby" and is a tool to interactively execute ruby
+# IRB stands for "interactive Ruby" and is a tool to interactively execute Ruby
 # expressions read from the standard input.
 #
 # The +irb+ command from your shell will start the interpreter.
 #
 # == Usage
 #
-# Use of irb is easy if you know ruby.
+# Use of irb is easy if you know Ruby.
 #
-# When executing irb, prompts are displayed as follows. Then, enter the ruby
+# When executing irb, prompts are displayed as follows. Then, enter the Ruby
 # expression. An input is executed when it is syntactically complete.
 #
 #     $ irb
@@ -101,7 +101,7 @@ STDOUT.sync = true
 #     IRB.conf[:USE_TRACER] = false
 #     IRB.conf[:IGNORE_SIGINT] = true
 #     IRB.conf[:IGNORE_EOF] = false
-#     IRB.conf[:PROMPT_MODE] = :DEFALUT
+#     IRB.conf[:PROMPT_MODE] = :DEFAULT
 #     IRB.conf[:PROMPT] = {...}
 #     IRB.conf[:DEBUG_LEVEL]=0
 #
@@ -221,7 +221,7 @@ STDOUT.sync = true
 # == Restrictions
 #
 # Because irb evaluates input immediately after it is syntactically complete,
-# the results may be slightly different than directly using ruby.
+# the results may be slightly different than directly using Ruby.
 #
 # == IRB Sessions
 #
@@ -337,7 +337,7 @@ STDOUT.sync = true
 #   # quit irb
 #   irb(main):010:0> exit
 module IRB
-  @RCS_ID='-$Id: irb.rb 39075 2013-02-05 15:57:19Z zzak $-'
+  @RCS_ID='-$Id: irb.rb 54263 2016-03-25 08:22:04Z usa $-'
 
   # An exception raised by IRB.irb_abort
   class Abort < Exception;end
@@ -526,7 +526,7 @@ module IRB
             print messages.join("\n"), "\n"
             unless lasts.empty?
               printf "... %d levels...\n", levels if levels > 0
-              print lasts.join("\n")
+              print lasts.join("\n"), "\n"
             end
             print "Maybe IRB bug!\n" if irb_bug
           end
